@echo OFF
rem  * ************************************************************************
rem  *                 CBLVSME8.cmd - a Windows Command File                  *
rem  *           This program is provided by SimoTime Technologies            *
rem  *              (C) Copyright 1987-2019 All Rights Reserved               *
rem  *                Web Site URL:   http://www.simotime.com                 *
rem  *                      e-mail:   helpdesk@simotime.com                   *
rem  * ************************************************************************
rem  *
rem  * Text   - Create various sequential files with 80-byte records.
rem  * Author - SimoTime Technologies
rem  * Date   - January 24, 1996
rem  *
rem  * This procedure uses the Microsoft "ECHO" command to pipe instream
rem  * data to an ASCII/Text file. The following terms are used.
rem  *
rem  * LSEQ - a Line Sequential File or ASCII/Text File
rem  * RSEQ - a Record Sequential File. This example uses a file of
rem  *        80-byte records that may be ASCII or EBCDIC encoded.
rem  * KSDS - a VSAM Key-Sequenced-Data-Set.
rem  *
rem  * 1. Use the Windows "ECHO" Create an LSEQ file to be used as input to
rem  *    create additional files.
rem  * 2. Read the LSEQ file and write an RSEQ, ASCII File.
rem  * 3. Read the LSEQ file and write an RSEQ, EBCDIC File.
rem  * 4. Read the RSEQ, ASCII file and write a KSDS, ASCII File.
rem  *
rem  * *******************************************************************
rem  * Step 1, Delete any previously created file...
rem  *
     call ..\ENV1BASE
     set CmdName=CBLVSME8
rem  *
     call SimoNOTE "*******************************************************%CmdName%.cmd"
     call SimoNOTE "Starting JobName %CmdName%"
:DeleteLSEQ
     call SimoNOTE "Identify JobStep DeleteLSEQ"
     set LSEQ0080=%BaseLib1%\DATA\Txt1\LSEQ0080.TXT
     if exist %LSEQ0080% del %LSEQ0080%
rem  *
rem  * *******************************************************************
rem  * Step 2, Create a new output file. Use the "echo" command provided
rem  *         with Microsoft Windows to pipe instream data to a new
rem  *         ASCII/Text file.
rem  *
:ExecuteCreateLSEQ
     call SimoNOTE "Identify JobStep ExecuteCreateLSEQ"
rem  ....:....1....:....2....:....3....:....4....:....5....:....6....:....7....:....8
echo 000100 Anderson       Adrian    111 Peachtree Plaza     Atlanta        GA 26101 >%LSEQ0080%
echo 000200 Brown          Billie    222 Baker Boulevard     Baltimore      MD 35702 >>%LSEQ0080%
echo 000300 Carson         Cameron   333 Crenshaw Blvd.      Cupertino      CA 96154 >>%LSEQ0080%
echo 000400 Davidson       Dion      444 Main Street         Wilmington     DE 27323 >>%LSEQ0080%
echo 000500 Everest        Evan      555 5TH Avenue          New York       NY 10341 >>%LSEQ0080%
echo 000600 Franklin       Francis   666 66TH Avenue         Bedrock        NY 11903 >>%LSEQ0080%
echo 000700 Garfunkel      Gwen      777 77TH Street         New York       NY 16539 >>%LSEQ0080%
echo 000800 Harrison       Hilary    888 88TH Street         Pocatello      ID 79684 >>%LSEQ0080%
echo 000900 Isley          Isabel    999 99TH Avenue         Indianapolis   IN 38762 >>%LSEQ0080%
echo 001000 Johnson        Jamie     1010 Paradise Drive     Larkspur       CA 90504 >>%LSEQ0080%
echo 001100 Kemper         Kelly     1111 Oak Circle         Kansas City    KS 55651 >>%LSEQ0080%
echo 001200 Lemond         Lesley    1212 Lockwood Road      Mohave Desert  AZ 80303 >>%LSEQ0080%
echo 001300 Mitchell       Marlow    1313 Miller Creek Road  Anywhere       TX 77123 >>%LSEQ0080%
echo 001400 Newman         Noel      1414 Park Avenue        Santa Monica   CA 90210 >>%LSEQ0080%
echo 001500 Osborn         Owen      1515 Center Stage       Rolling Rock   PA 36613 >>%LSEQ0080%
echo 001600 Powell         Pierce    PO Box 1616             Ventura        CA 97712 >>%LSEQ0080%
echo 001700 Quigley        Quincy    1717 Farm Hill Road     Oshkosh        WI 43389 >>%LSEQ0080%
echo 001800 Ripley         Ray       1818 Alien Lane         Wayout         KS 55405 >>%LSEQ0080%
echo 001900 Smith          Sammy     1919 Carnoustie Drive   Novato         CA 94919 >>%LSEQ0080%
echo 002000 Tucker         Taylor    2020 Sanger Lane        St. Paul       MN 43998 >>%LSEQ0080%
echo 002100 Underwood      Ulysses   2121 Wall Street        New York       NY 17623 >>%LSEQ0080%
echo 002200 Van Etten      Valerie   2222 Vine Street        Hollywood      CA 98775 >>%LSEQ0080%
echo 002300 Wilson         Wiley     2323 Main Street        Boston         MA 01472 >>%LSEQ0080%
echo 002400 Xray           Xavier    2424 24TH Street        Nashville      TN 44190 >>%LSEQ0080%
echo 002500 Young          Yanni     2525 Yonge Street       Toronto        ON 6B74A6>>%LSEQ0080%
echo 002600 Zenith         Zebulon   2626 26TH Street        Dallas         TX 71922 >>%LSEQ0080%
echo 123456 Doe            John      123 Main Street         Anywhere       OR 88156 >>%LSEQ0080%
rem  *
     if not exist %LSEQ0080% set JobStatus=0002
     if not "%JobStatus%" == "0000" goto EojNok
     call SimoNOTE "Produced DataSet %LSEQ0080%"
rem  *
:ConvertLSEQtoRSEQasc
rem  *
rem  * *******************************************************************
rem  * Step 3, Read the previously created Line Sequential File (LSEQ)
rem  *         and write a Record Sequential File (RSEQ) with 80-byte,
rem  *         ASCII-encoded records.
rem  *         Note: The convert program (CV80ALAR) was generated using
rem  *               SimoTime Technology.
rem  *
     call SimoNOTE "Identify JobStep ConvertLSEQtoRSEQasc"
     set GETLS080=%LSEQ0080%
     set PUTRS080=%BaseLib1%\DATA\Asc1\SIMOTIME.DATA.QSAM0080.DAT
     if exist %PUTRS080% del %PUTRS080%
     run CV80ALAR
     if not exist %PUTRS080% set JobStatus=0003
     if not "%JobStatus%" == "0000" goto EojNok
     call SimoNOTE "Produced DataSet %PUTRS080%"
rem  *
:ConvertLSEQtoRSEQebc
rem  *
rem  * *******************************************************************
rem  * Step 4, Read the previously created Line Sequential File (LSEQ)
rem  *         and write a Record Sequential File (RSEQ) with 80-byte,
rem  *         EBCDIC-encoded records.
rem  *         Note: The convert program (CV80ALER) was generated using
rem  *               SimoTime Technology.
rem  *
     call SimoNOTE "Identify JobStep ConvertLSEQtoRSEQebc"
     set GETLS080=%LSEQ0080%
     set PUTRS080=%BaseLib1%\DATA\Ebc1\SIMOTIME.DATA.QSAM0080.DAT
     if exist %PUTRS080% del %PUTRS080%
     run CV80ALER
     if not exist %PUTRS080% set JobStatus=0004
     if not "%JobStatus%" == "0000" goto EojNok
     call SimoNOTE "Produced DataSet %PUTRS080%"
rem  *
:ConvertLSEQtoRSEQebc
rem  *
rem  * *******************************************************************
rem  * Step 5, Read a previously created Record Sequential File (RSEQ),
rem  *         write a VSAM, KSDS  with 80-byte, ASCII-encoded records.
rem  *         Note: The convert program (KSLOADC1) was generated using
rem  *               SimoTime Technology.
rem  *
     call SimoNOTE "Identify JobStep ConvertRSEQtoKSDS"
     set QSAM0080=%BaseLib1%\DATA\Asc1\SIMOTIME.DATA.QSAM0080.DAT
     set KSDS0080=%BaseLib1%\DATA\Asc1\SIMOTIME.DATA.CUST0080.DAT
     if exist %KSDS0080% del %KSDS0080%
     run KSLOADC1
     if not exist %KSDS0080% set JobStatus=0004
     if not "%JobStatus%" == "0000" goto EojNok
     call SimoNOTE "Produced DataSet %KSDS0080%"
rem  *
rem  * *******************************************************************
rem  *
:EojAok
     call SimoNOTE "Finished JobName %CmdName%, Job Status is %JobStatus%"
     goto :End
:EojNok
     call SimoNOTE "ABENDING JobName %CmdName%, Job Status is %JobStatus%"
:End
     call SimoNOTE "Conclude SysLog is %SYSLOG%"
     if not "%1" == "nopause" pause
